<?php
/**
 * NGO Organization: Customizer
 *
 * @package NGO Organization
 * @subpackage ngo_organization
 */

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function ngo_organization_customize_register( $wp_customize ) {

	//add home page setting pannel
	$wp_customize->add_panel( 'ngo_organization_panel_id', array(
	    'priority' => 10,
	    'capability' => 'edit_theme_options',
	    'theme_supports' => '',
	    'title' => __( 'Custom Home page', 'ngo-organization' ),
	    'description' => __( 'Description of what this panel does.', 'ngo-organization' ),
	) );

	//Sidebar Position
	$wp_customize->add_section('ngo_organization_tp_general_settings',array(
		'title' => __('TP General Option', 'ngo-organization'),
		'priority' => 10,
		'panel' => 'ngo_organization_panel_id'
	) );

   $wp_customize->add_setting('ngo_organization_tp_body_layout_settings',array(
		'default' => 'Full',
		'sanitize_callback' => 'ngo_organization_sanitize_choices'
	));
   $wp_customize->add_control('ngo_organization_tp_body_layout_settings',array(
        'type' => 'radio',
        'label'     => __('Body Layout Setting', 'ngo-organization'),
        'description'   => __('This option work for complete body, if you want to set the complete website in container.', 'ngo-organization'),
        'section' => 'ngo_organization_tp_general_settings',
        'choices' => array(
            'Full' => __('Full','ngo-organization'),
            'Container' => __('Container','ngo-organization'),
            'Container Fluid' => __('Container Fluid','ngo-organization')
        ),
	) );

   // Add Settings and Controls for Post Layout
	$wp_customize->add_setting('ngo_organization_sidebar_post_layout',array(
      'default' => 'right',
      'sanitize_callback' => 'ngo_organization_sanitize_choices'
	));
	$wp_customize->add_control('ngo_organization_sidebar_post_layout',array(
        'type' => 'radio',
        'label'     => __('Theme Sidebar Position', 'ngo-organization'),
        'description'   => __('This option work for blog page, blog single page, archive page and search page.', 'ngo-organization'),
        'section' => 'ngo_organization_tp_general_settings',
        'choices' => array(
            'full' => __('Full','ngo-organization'),
            'left' => __('Left','ngo-organization'),
            'right' => __('Right','ngo-organization'),
            'three-column' => __('Three Columns','ngo-organization'),
            'four-column' => __('Four Columns','ngo-organization'),
            'grid' => __('Grid Layout','ngo-organization')
        ),
	) );

	// Add Settings and Controls for Page Layout
	$wp_customize->add_setting('ngo_organization_sidebar_page_layout',array(
        'default' => 'right',
        'sanitize_callback' => 'ngo_organization_sanitize_choices'
	));
	$wp_customize->add_control('ngo_organization_sidebar_page_layout',array(
        'type' => 'radio',
        'label'     => __('Page Sidebar Position', 'ngo-organization'),
        'description'   => __('This option work for pages.', 'ngo-organization'),
        'section' => 'ngo_organization_tp_general_settings',
        'choices' => array(
            'full' => __('Full','ngo-organization'),
            'left' => __('Left','ngo-organization'),
            'right' => __('Right','ngo-organization')
        ),
	) );

	//TP Blog Option
	$wp_customize->add_section('ngo_organization_blog_option',array(
     	'title' => __('TP Blog Option', 'ngo-organization'),
     	'priority' => 20,
     	'panel' => 'ngo_organization_panel_id'
   ) );

    $wp_customize->add_setting('ngo_organization_remove_date',array(
       'default' => true,
       'sanitize_callback'	=> 'ngo_organization_sanitize_checkbox'
    ));
    $wp_customize->add_control('ngo_organization_remove_date',array(
       'type' => 'checkbox',
       'label' => __('Show / Hide Date Option','ngo-organization'),
       'section' => 'ngo_organization_blog_option',
    ));
    $wp_customize->selective_refresh->add_partial( 'ngo_organization_remove_date', array(
		'selector' => '.entry-date',
		'render_callback' => 'ngo_organization_customize_partial_ngo_organization_remove_date',
	) );

    $wp_customize->add_setting('ngo_organization_remove_author',array(
       'default' => true,
       'sanitize_callback'	=> 'ngo_organization_sanitize_checkbox'
    ));
    $wp_customize->add_control('ngo_organization_remove_author',array(
       'type' => 'checkbox',
       'label' => __('Show / Hide Author Option','ngo-organization'),
       'section' => 'ngo_organization_blog_option',
    ));
    $wp_customize->selective_refresh->add_partial( 'ngo_organization_remove_author', array(
		'selector' => '.entry-author',
		'render_callback' => 'ngo_organization_customize_partial_ngo_organization_remove_author',
	) );

    $wp_customize->add_setting('ngo_organization_remove_comments',array(
       'default' => true,
       'sanitize_callback'	=> 'ngo_organization_sanitize_checkbox'
    ));
    $wp_customize->add_control('ngo_organization_remove_comments',array(
       'type' => 'checkbox',
       'label' => __('Show / Hide Comment Option','ngo-organization'),
       'section' => 'ngo_organization_blog_option',
    ));
    $wp_customize->selective_refresh->add_partial( 'ngo_organization_remove_comments', array(
		'selector' => '.entry-comments',
		'render_callback' => 'ngo_organization_customize_partial_ngo_organization_remove_comments',
	) );

    $wp_customize->add_setting('ngo_organization_remove_tags',array(
       'default' => true,
       'sanitize_callback'	=> 'ngo_organization_sanitize_checkbox'
    ));
    $wp_customize->add_control('ngo_organization_remove_tags',array(
       'type' => 'checkbox',
       'label' => __('Show / Hide Tags Option','ngo-organization'),
       'section' => 'ngo_organization_blog_option',
    ));
    $wp_customize->selective_refresh->add_partial( 'ngo_organization_remove_tags', array(
		'selector' => '.box-content a[rel="tag"]',
		'render_callback' => 'ngo_organization_customize_partial_ngo_organization_remove_tags',
	) );

    $wp_customize->add_setting('ngo_organization_remove_read_button',array(
       'default' => true,
       'sanitize_callback'	=> 'ngo_organization_sanitize_checkbox'
    ));
    $wp_customize->add_control('ngo_organization_remove_read_button',array(
       'type' => 'checkbox',
       'label' => __('Show / Hide Read More Button','ngo-organization'),
       'section' => 'ngo_organization_blog_option',
    ));
    $wp_customize->selective_refresh->add_partial( 'ngo_organization_remove_read_button', array(
		'selector' => '.readmore-btn',
		'render_callback' => 'ngo_organization_customize_partial_ngo_organization_remove_read_button',
	) );

    $wp_customize->add_setting('ngo_organization_read_more_text',array(
		'default'=> __('Read More','ngo-organization'),
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('ngo_organization_read_more_text',array(
		'label'	=> __('Edit Button Text','ngo-organization'),
		'section'=> 'ngo_organization_blog_option',
		'type'=> 'text'
	));

	$wp_customize->add_setting( 'ngo_organization_excerpt_count', array(
		'default'              => 35,
		'type'                 => 'theme_mod',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'ngo_organization_sanitize_number_range',
		'sanitize_js_callback' => 'absint',
	) );
	$wp_customize->add_control( 'ngo_organization_excerpt_count', array(
		'label'       => esc_html__( 'Edit Excerpt Limit','ngo-organization' ),
		'section'     => 'ngo_organization_blog_option',
		'type'        => 'number',
		'input_attrs' => array(
			'step'             => 2,
			'min'              => 0,
			'max'              => 50,
		),
	) );

	// Top Bar
	$wp_customize->add_section( 'ngo_organization_topbar', array(
    	'title'      => __( 'Contact Details', 'ngo-organization' ),
    	'description' => __( 'Add your contact details', 'ngo-organization' ),
    	'priority' => 30,
		'panel' => 'ngo_organization_panel_id'
	) );

	$wp_customize->add_setting('ngo_organization_phone_number',array(
		'default'=> '',
		'sanitize_callback'	=> 'ngo_organization_sanitize_phone_number'
	));
	$wp_customize->add_control('ngo_organization_phone_number',array(
		'label'	=> __('Add Phone Number','ngo-organization'),
		'section'=> 'ngo_organization_topbar',
		'type'=> 'text'
	));
	$wp_customize->selective_refresh->add_partial( 'ngo_organization_phone_number', array(
		'selector' => '.top-header span',
		'render_callback' => 'ngo_organization_customize_partial_ngo_organization_phone_number',
	) );

	$wp_customize->add_setting('ngo_organization_email_address',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_email'
	));
	$wp_customize->add_control('ngo_organization_email_address',array(
		'label'	=> __('Add Mail Address','ngo-organization'),
		'section'=> 'ngo_organization_topbar',
		'type'=> 'text'
	));

	$wp_customize->add_setting('ngo_organization_register_button',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('ngo_organization_register_button',array(
		'label'	=> __('Add Register Text','ngo-organization'),
		'section'=> 'ngo_organization_topbar',
		'type'=> 'text'
	));

	$wp_customize->add_setting('ngo_organization_register_button_link',array(
		'default'=> '',
		'sanitize_callback'	=> 'esc_url_raw'
	));
	$wp_customize->add_control('ngo_organization_register_button_link',array(
		'label'	=> __('Add Register URL','ngo-organization'),
		'section'=> 'ngo_organization_topbar',
		'type'=> 'url'
	));

	$wp_customize->add_setting('ngo_organization_login_button',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('ngo_organization_login_button',array(
		'label'	=> __('Add Login Text','ngo-organization'),
		'section'=> 'ngo_organization_topbar',
		'type'=> 'text'
	));

	$wp_customize->add_setting('ngo_organization_login_button_link',array(
		'default'=> '',
		'sanitize_callback'	=> 'esc_url_raw'
	));
	$wp_customize->add_control('ngo_organization_login_button_link',array(
		'label'	=> __('Add Login URL','ngo-organization'),
		'section'=> 'ngo_organization_topbar',
		'type'=> 'url'
	));

	$wp_customize->add_setting('ngo_organization_donate_button_1',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('ngo_organization_donate_button_1',array(
		'label'	=> __('Add Donate 1 Text','ngo-organization'),
		'section'=> 'ngo_organization_topbar',
		'type'=> 'text'
	));

	$wp_customize->add_setting('ngo_organization_donate_button_1_link',array(
		'default'=> '',
		'sanitize_callback'	=> 'esc_url_raw'
	));
	$wp_customize->add_control('ngo_organization_donate_button_1_link',array(
		'label'	=> __('Add Donate 1 URL','ngo-organization'),
		'section'=> 'ngo_organization_topbar',
		'type'=> 'url'
	));

	$wp_customize->add_setting('ngo_organization_donate_button_2',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('ngo_organization_donate_button_2',array(
		'label'	=> __('Add Donate 2 Text','ngo-organization'),
		'section'=> 'ngo_organization_topbar',
		'type'=> 'text'
	));

	$wp_customize->add_setting('ngo_organization_donate_button_2_link',array(
		'default'=> '',
		'sanitize_callback'	=> 'esc_url_raw'
	));
	$wp_customize->add_control('ngo_organization_donate_button_2_link',array(
		'label'	=> __('Add Donate 2 URL','ngo-organization'),
		'section'=> 'ngo_organization_topbar',
		'type'=> 'url'
	));

	// Social Media
	$wp_customize->add_section( 'ngo_organization_social_media', array(
    	'title'      => __( 'Social Media Links', 'ngo-organization' ),
    	'description' => __( 'Add your Social Links', 'ngo-organization' ),
    	'priority' => 40,
		'panel' => 'ngo_organization_panel_id'
	) );

	$wp_customize->add_setting('ngo_organization_facebook_url',array(
		'default'=> '',
		'sanitize_callback'	=> 'esc_url_raw'
	));
	$wp_customize->add_control('ngo_organization_facebook_url',array(
		'label'	=> __('Facebook Link','ngo-organization'),
		'section'=> 'ngo_organization_social_media',
		'type'=> 'url'
	));
	$wp_customize->selective_refresh->add_partial( 'ngo_organization_facebook_url', array(
		'selector' => '.media-links a',
		'render_callback' => 'ngo_organization_customize_partial_ngo_organization_facebook_url',
	) );

	$wp_customize->add_setting('ngo_organization_twitter_url',array(
		'default'=> '',
		'sanitize_callback'	=> 'esc_url_raw'
	));
	$wp_customize->add_control('ngo_organization_twitter_url',array(
		'label'	=> __('Twitter Link','ngo-organization'),
		'section'=> 'ngo_organization_social_media',
		'type'=> 'url'
	));

	$wp_customize->add_setting('ngo_organization_instagram_url',array(
		'default'=> '',
		'sanitize_callback'	=> 'esc_url_raw'
	));
	$wp_customize->add_control('ngo_organization_instagram_url',array(
		'label'	=> __('Instagram Link','ngo-organization'),
		'section'=> 'ngo_organization_social_media',
		'type'=> 'url'
	));

	$wp_customize->add_setting('ngo_organization_youtube_url',array(
		'default'=> '',
		'sanitize_callback'	=> 'esc_url_raw'
	));
	$wp_customize->add_control('ngo_organization_youtube_url',array(
		'label'	=> __('YouTube Link','ngo-organization'),
		'section'=> 'ngo_organization_social_media',
		'type'=> 'url'
	));

	$wp_customize->add_setting('ngo_organization_pint_url',array(
		'default'=> '',
		'sanitize_callback'	=> 'esc_url_raw'
	));
	$wp_customize->add_control('ngo_organization_pint_url',array(
		'label'	=> __('Pinterest Link','ngo-organization'),
		'section'=> 'ngo_organization_social_media',
		'type'=> 'url'
	));

	//home page slider
	$wp_customize->add_section( 'ngo_organization_slider_section' , array(
    	'title'      => __( 'Slider Section', 'ngo-organization' ),
    	'priority' => 50,
		'panel' => 'ngo_organization_panel_id'
	) );

	$wp_customize->add_setting('ngo_organization_slider_arrows',array(
       'default' => false,
       'sanitize_callback'	=> 'ngo_organization_sanitize_checkbox'
    ));
    $wp_customize->add_control('ngo_organization_slider_arrows',array(
       'type' => 'checkbox',
       'label' => __('Show / Hide slider','ngo-organization'),
       'section' => 'ngo_organization_slider_section',
    ));
    $wp_customize->selective_refresh->add_partial( 'ngo_organization_slider_arrows', array(
		'selector' => '#slider .carousel-caption',
		'render_callback' => 'ngo_organization_customize_partial_ngo_organization_slider_arrows',
	) );

	for ( $ngo_organization_count = 1; $ngo_organization_count <= 4; $ngo_organization_count++ ) {

		$wp_customize->add_setting( 'ngo_organization_slider_page' . $ngo_organization_count, array(
			'default'           => '',
			'sanitize_callback' => 'ngo_organization_sanitize_dropdown_pages'
		) );

		$wp_customize->add_control( 'ngo_organization_slider_page' . $ngo_organization_count, array(
			'label'    => __( 'Select Slide Image Page', 'ngo-organization' ),
			'section'  => 'ngo_organization_slider_section',
			'type'     => 'dropdown-pages'
		) );
	}

	//OUR FUNDS
	$wp_customize->add_section( 'ngo_organization_our_fund_section' , array(
    	'title'      => __( 'Our Funds Section', 'ngo-organization' ),
    	'priority' => 60,
		'panel' => 'ngo_organization_panel_id'
	) );

	$ngo_organization_categories = get_categories();
	$cats = array();
	$i = 0;
	$ngo_organization_offer_cat[]= 'select';
	foreach($ngo_organization_categories as $category){
		if($i==0){
			$default = $category->slug;
			$i++;
		}
		$ngo_organization_offer_cat[$category->slug] = $category->name;
	}

	$wp_customize->add_setting('ngo_organization_our_fund_section_category',array(
		'default'	=> 'select',
		'sanitize_callback' => 'ngo_organization_sanitize_choices',
	));
	$wp_customize->add_control('ngo_organization_our_fund_section_category',array(
		'type'    => 'select',
		'choices' => $ngo_organization_offer_cat,
		'label' => __('Select Category','ngo-organization'),
		'section' => 'ngo_organization_our_fund_section',
	));

	//footer
	$wp_customize->add_section('ngo_organization_footer_section',array(
		'title'	=> __('Footer Text','ngo-organization'),
		'description'	=> __('Add copyright text.','ngo-organization'),
		'panel' => 'ngo_organization_panel_id'
	));

	$wp_customize->add_setting('ngo_organization_footer_text',array(
		'default'	=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('ngo_organization_footer_text',array(
		'label'	=> __('Copyright Text','ngo-organization'),
		'section'	=> 'ngo_organization_footer_section',
		'type'		=> 'text'
	));
	$wp_customize->selective_refresh->add_partial( 'ngo_organization_footer_text', array(
		'selector' => '#footer p',
		'render_callback' => 'construction_hub_customize_partial_ngo_organization_footer_text',
	) );

	$wp_customize->add_setting('ngo_organization_return_to_header',array(
		'default' => true,
		'sanitize_callback'	=> 'ngo_organization_sanitize_checkbox'
	));
	$wp_customize->add_control('ngo_organization_return_to_header',array(
		'type' => 'checkbox',
		'label' => __('Show / Hide Return to header','ngo-organization'),
		'section' => 'ngo_organization_footer_section',
	));

   // Add Settings and Controls for Scroll top
	$wp_customize->add_setting('ngo_organization_scroll_top_position',array(
        'default' => 'Right',
        'sanitize_callback' => 'ngo_organization_sanitize_choices'
	));
	$wp_customize->add_control('ngo_organization_scroll_top_position',array(
        'type' => 'radio',
        'label'     => __('Scroll to top Position', 'ngo-organization'),
        'description'   => __('This option work for scroll to top', 'ngo-organization'),
        'section' => 'ngo_organization_footer_section',
        'choices' => array(
            'Right' => __('Right','ngo-organization'),
            'Left' => __('Left','ngo-organization'),
            'Center' => __('Center','ngo-organization')
        ),
	) );

	$wp_customize->get_setting( 'blogname' )->transport          = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport   = 'postMessage';

	$wp_customize->selective_refresh->add_partial( 'blogname', array(
		'selector' => '.site-title a',
		'render_callback' => 'ngo_organization_customize_partial_blogname',
	) );
	$wp_customize->selective_refresh->add_partial( 'blogdescription', array(
		'selector' => '.site-description',
		'render_callback' => 'ngo_organization_customize_partial_blogdescription',
	) );

	$wp_customize->add_setting('ngo_organization_site_title_text',array(
       'default' => true,
       'sanitize_callback'	=> 'ngo_organization_sanitize_checkbox'
    ));
    $wp_customize->add_control('ngo_organization_site_title_text',array(
       'type' => 'checkbox',
       'label' => __('Show / Hide Site Title','ngo-organization'),
       'section' => 'title_tagline',
    ));

		// logo site title size
		$wp_customize->add_setting('ngo_organization_site_title_font_size',array(
			'default'	=> 30,
			'sanitize_callback'	=> 'ngo_organization_sanitize_number_absint'
		));
		$wp_customize->add_control('ngo_organization_site_title_font_size',array(
			'label'	=> __('Site Title Font Size in PX','ngo-organization'),
			'section'	=> 'title_tagline',
			'setting'	=> 'ngo_organization_site_title_font_size',
			'type'	=> 'number',
			'input_attrs' => array(
				'step'             => 1,
				'min'              => 0,
				'max'              => 100,
			),
		));

    $wp_customize->add_setting('ngo_organization_site_tagline_text',array(
       'default' => false,
       'sanitize_callback'	=> 'ngo_organization_sanitize_checkbox'
    ));
    $wp_customize->add_control('ngo_organization_site_tagline_text',array(
       'type' => 'checkbox',
       'label' => __('Show / Hide Tagline','ngo-organization'),
       'section' => 'title_tagline',
    ));


		// logo site tagline size
	$wp_customize->add_setting('ngo_organization_site_tagline_font_size',array(
		'default'	=> 15,
		'sanitize_callback'	=> 'ngo_organization_sanitize_number_absint'
	));
	$wp_customize->add_control('ngo_organization_site_tagline_font_size',array(
		'label'	=> __('Site Tagline Font Size in PX','ngo-organization'),
		'section'	=> 'title_tagline',
		'setting'	=> 'ngo_organization_site_tagline_font_size',
		'type'	=> 'number',
		'input_attrs' => array(
			'step'             => 1,
			'min'              => 0,
			'max'              => 50,
		),
	));

    $wp_customize->add_setting('ngo_organization_logo_width',array(
		'default' => 100,
		'sanitize_callback'	=> 'ngo_organization_sanitize_number_absint'
	));
	 $wp_customize->add_control('ngo_organization_logo_width',array(
		'label'	=> esc_html__('Here You Can Customize Your Logo Size','ngo-organization'),
		'section'	=> 'title_tagline',
		'type'		=> 'number'
	));

	$wp_customize->add_setting('ngo_organization_logo_settings',array(
        'default' => 'Different Line',
        'sanitize_callback' => 'ngo_organization_sanitize_choices'
	));
    $wp_customize->add_control('ngo_organization_logo_settings',array(
        'type' => 'radio',
        'label'     => __('Logo Layout Settings', 'ngo-organization'),
        'description'   => __('Here you have two options 1. Logo and Site tite in differnt line. 2. Logo and Site title in same line.', 'ngo-organization'),
        'section' => 'title_tagline',
        'choices' => array(
            'Different Line' => __('Different Line','ngo-organization'),
            'Same Line' => __('Same Line','ngo-organization')
        ),
	) );

	$wp_customize->add_setting('ngo_organization_per_columns',array(
		'default'=> 3,
		'sanitize_callback'	=> 'ngo_organization_sanitize_number_absint'
	));
	$wp_customize->add_control('ngo_organization_per_columns',array(
		'label'	=> __('Product Per Row','ngo-organization'),
		'section'=> 'woocommerce_product_catalog',
		'type'=> 'number'
	));

	$wp_customize->add_setting('ngo_organization_product_per_page',array(
		'default'=> 9,
		'sanitize_callback'	=> 'ngo_organization_sanitize_number_absint'
	));
	$wp_customize->add_control('ngo_organization_product_per_page',array(
		'label'	=> __('Product Per Page','ngo-organization'),
		'section'=> 'woocommerce_product_catalog',
		'type'=> 'number'
	));

    $wp_customize->add_setting('ngo_organization_product_sidebar',array(
       'default' => true,
       'sanitize_callback'	=> 'ngo_organization_sanitize_checkbox'
    ));
    $wp_customize->add_control('ngo_organization_product_sidebar',array(
       'type' => 'checkbox',
       'label' => __('Show / Hide Shop page sidebar','ngo-organization'),
       'section' => 'woocommerce_product_catalog',
    ));

    $wp_customize->add_setting('ngo_organization_single_product_sidebar',array(
       'default' => true,
       'sanitize_callback'	=> 'ngo_organization_sanitize_checkbox'
    ));
    $wp_customize->add_control('ngo_organization_single_product_sidebar',array(
       'type' => 'checkbox',
       'label' => __('Show / Hide Product page sidebar','ngo-organization'),
       'section' => 'woocommerce_product_catalog',
    ));
}
add_action( 'customize_register', 'ngo_organization_customize_register' );

/**
 * Render the site title for the selective refresh partial.
 *
 * @since NGO Organization 1.0
 * @see ngo_organization_customize_register()
 *
 * @return void
 */
function ngo_organization_customize_partial_blogname() {
	bloginfo( 'name' );
}

/**
 * Render the site tagline for the selective refresh partial.
 *
 * @since NGO Organization 1.0
 * @see ngo_organization_customize_register()
 *
 * @return void
 */
function ngo_organization_customize_partial_blogdescription() {
	bloginfo( 'description' );
}

if ( ! defined( 'NGO_ORGANIZATION_PRO_THEME_NAME' ) ) {
	define( 'NGO_ORGANIZATION_PRO_THEME_NAME', esc_html__( 'NGO Organization Pro Theme', 'ngo-organization' ));
}
if ( ! defined( 'NGO_ORGANIZATION_PRO_THEME_URL' ) ) {
	define( 'NGO_ORGANIZATION_PRO_THEME_URL', esc_url('https://www.themespride.com/themes/ngo-organization-wordpress-theme/'));
}

/**
 * Singleton class for handling the theme's customizer integration.
 *
 * @since  1.0.0
 * @access public
 */
final class NGO_Organization_Customize {

	/**
	 * Returns the instance.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return object
	 */
	public static function get_instance() {

		static $instance = null;

		if ( is_null( $instance ) ) {
			$instance = new self;
			$instance->setup_actions();
		}

		return $instance;
	}

	/**
	 * Constructor method.
	 *
	 * @since  1.0.0
	 * @access private
	 * @return void
	 */
	private function __construct() {}

	/**
	 * Sets up initial actions.
	 *
	 * @since  1.0.0
	 * @access private
	 * @return void
	 */
	private function setup_actions() {

		// Register panels, sections, settings, controls, and partials.
		add_action( 'customize_register', array( $this, 'sections' ) );

		// Register scripts and styles for the controls.
		add_action( 'customize_controls_enqueue_scripts', array( $this, 'enqueue_control_scripts' ), 0 );
	}

	/**
	 * Sets up the customizer sections.
	 *
	 * @since  1.0.0
	 * @access public
	 * @param  object  $manager
	 * @return void
	 */
	public function sections( $manager ) {

		// Load custom sections.
		load_template( trailingslashit( get_template_directory() ) . '/inc/section-pro.php' );

		// Register custom section types.
		$manager->register_section_type( 'NGO_Organization_Customize_Section_Pro' );

		// Register sections.
		$manager->add_section(
			new NGO_Organization_Customize_Section_Pro(
				$manager,
				'ngo_organization_section_pro',
				array(
					'priority'   => 9,
					'title'    => NGO_ORGANIZATION_PRO_THEME_NAME,
					'pro_text' => esc_html__( 'Upgrade Pro', 'ngo-organization' ),
					'pro_url'  => esc_url( NGO_ORGANIZATION_PRO_THEME_URL, 'ngo-organization' ),
				)
			)
		);
	}

	/**
	 * Loads theme customizer CSS.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return void
	 */
	public function enqueue_control_scripts() {

		wp_enqueue_script( 'ngo-organization-customize-controls', trailingslashit( esc_url( get_template_directory_uri() ) ) . '/assets/js/customize-controls.js', array( 'customize-controls' ) );

		wp_enqueue_style( 'ngo-organization-customize-controls', trailingslashit( esc_url( get_template_directory_uri() ) ) . '/assets/css/customize-controls.css' );
	}
}

// Doing this customizer thang!
NGO_Organization_Customize::get_instance();
